//[mahjong-utils](../../../../index.md)/[mahjongutils.hanhu](../../index.md)/[ChildPoint](../index.md)/[Companion](index.md)/[Baiman](-baiman.md)

# Baiman

[common]\
val [Baiman](-baiman.md): [ChildPoint](../index.md)
